let mongo_settings = JSON.parse('{{mod_vars.mongo_settings|json_encode|raw}}');
let mongo_file_editor = null;
function setInputFilter(textbox, inputFilter) {
    ["input", "keydown", "keyup", "mousedown", "mouseup", "select", "contextmenu", "drop"].forEach(function (event) {
        textbox.addEventListener(event, function () {
            if (inputFilter(this.value)) {
                this.oldValue = this.value;
                this.oldSelectionStart = this.selectionStart;
                this.oldSelectionEnd = this.selectionEnd;
            } else if (this.hasOwnProperty("oldValue")) {
                this.value = this.oldValue;
                this.setSelectionRange(this.oldSelectionStart, this.oldSelectionEnd);
            } else {
                this.value = "";
            }
        });
    });
}
function BindSettingsTab(){
    setInputFilter(document.getElementById("_mongo_settings_port_"), function (value) {
        return /^\d*$/.test(value);
    });
    setInputFilter(document.getElementById("_mongo_settings_incomming_"), function (value) {
        return /^\d*$/.test(value);
    });
    $('[data-toggle="tooltip"]').tooltip()
    $('[data-toggle="popover"]').popover();
    $("[data-toggle='popover']").on('show.bs.popover', function () {
        $("[data-toggle='tooltip']").tooltip('hide');
    });
    $('body').on('click', function (e) { // ADD LISTENER TO CLOSE POPOVER
        $('[data-toggle="popover"]').each(function () {
            //the 'is' for buttons that trigger popups
            //the 'has' for icons within a button that triggers a popup
            if (!$(this).is(e.target) && $(this).has(e.target).length === 0 && $('.popover').has(e.target).length === 0) {
                $(this).popover('hide');
            }
        });
    });
    setValuesToForm();
    mongo_file_editor = CodeMirror.fromTextArea(document.getElementById("_mongo_file_editor_area_"), {
        lineNumbers: true,
        matchBrackets: true,
        styleActiveLine: true,
        theme: "ambiance"
    });
}
function advanceTab() {
    setTimeout(function () {
        mongo_file_editor.refresh();
    }, 200);
}
function setValuesToForm(){
    $('#_mongo_settings_port_').val(mongo_settings.port);
    $('#_mongo_settings_log_path').val(mongo_settings.path);
    $('#_mongo_settings_verbosity_level_').val(mongo_settings.verbosity);
    $('#_mongo_settings_log_rotate_').val(mongo_settings.log_rotate);
    $('#_mongo_settings_bind_ip_').val(mongo_settings.bind_ip);
    $('#_mongo_settings_incomming_').val(mongo_settings.max_incoming_connections);
    if (mongo_settings.trace_all_exceptions === true){
        $('#_mongo_settings_trace_yes').trigger('click');
    }
    if (mongo_settings.wire_object_check === false){
        $('#_mongo_settings_wire_no').trigger('click');
    }
    if (mongo_settings.ipv6 === true){
        $('#_mongo_settings_ipv6_yes').trigger('click');
    }
    if (mongo_settings.log_append === true){
        $('#_mongo_settings_logappend_yes').trigger('click');
    }
    if (mongo_settings.authorization != 'disabled'){
        $('#_mongo_settings_role_yes').trigger('click');
    }
}
function MongoSaveSettingsFile(elem, restart){
    MongoSaveSettings(elem, restart, true);
}
function MongoSaveSettings(elem, restart, file){
    if (restart !== undefined){
        $('#_mongodb_status_loader_title_').text('{{lang.LABMON137}}');
        slideToggle('.mongodb-status-panel', '.mongodb-tabs-container-main');
        handleBtns();
    }else{
        handleButtons(elem, 'fa-floppy-o');
    }
    function UnlockUI(status, new_db_list){
        if (restart !== undefined) {
            if (status == 'running'){
                slideToggle('.mongodb-tabs-container-main', '.mongodb-status-panel', function(){
                    $('.running-screen-twice').show();
                    $('.not-running-screen').hide();
                });
                $('.on-not-running').fadeOut('fast', function () {
                    $('.on-running').fadeIn('fast');
                    handleButtons('.on-not-running', 'fa-play', true);
                });
                if (database_list.length === 0 && new_db_list !== undefined){
                    database_list = new_db_list;
                    MongoDBList();
                }
            }else{
                $('.on-running').fadeOut('fast', function () {
                    $('.on-not-running').fadeIn('fast');
                    handleBtns(false);
                });
                slideToggle('.not-running-screen-panel', '.mongodb-status-panel', function(){
                    $('.running-screen-twice').hide();
                    $('.not-running-screen').show();
                });
            }
            
            handleBtns(false);
        }else{
            handleButtons(elem, 'fa-floppy-o', true);
        }
        
    }
    function handleBtns(st) {
        handleButtons('#_btn_stop_sidebar_', 'fa-stop', st);
        handleButtons('#_btn_restart_sidebar_', 'fa-refresh', st);
    }
    function alertSuccess(status){
        let message = '{{lang.LABMON138}}';
        let tag_style = 'success-notice';
        if (restart !== undefined && status != 'running'){
            message = '{{lang.LABMON139}} "systemctl status mongod.service"';
            tag_style = 'warning-notice';
            $('#_mongodb_status_holder').text(statusTranslator('stopped'));
        }else if(restart === undefined){
            message = '{{lang.LABMON140}}';
        }
        $.gritter.add({ 
            title: '{{lang.LABMON18}}',
            text: message,
            time: 5500,
            close_icon: '',
            icon: 'icomoon-icon-quill-2',
            class_name: tag_style
        });
    }
    if(file === true){
        let file_content = mongo_file_editor.getValue();
        sendMongoDBSettingsFile(file_content, restart === undefined ? 0 : 1,
            function (response) {
                mongo_settings = response.settings;
                setValuesToForm();
                UnlockUI(response.status_server, response.db_list !== null ? response.db_list : undefined);
                alertSuccess(response.status_server);
            }, function () {
                UnlockUI('running');
            });
    }else{
        let settings_form = {
            port: $('#_mongo_settings_port_').val(),
            path: $('#_mongo_settings_log_path').val(),
            verbosity: $('#_mongo_settings_verbosity_level_').val(),
            trace_all_exceptions: $('#_mongo_settings_trace_no').is(':checked') ? false : true,
            log_append: $('#_mongo_settings_logappend_no').is(':checked') ? false : true,
            log_rotate: $('#_mongo_settings_log_rotate_').val(),
            bind_ip: $('#_mongo_settings_bind_ip_').val(),
            max_incoming_connections: $('#_mongo_settings_incomming_').val(),
            wire_object_check: $('#_mongo_settings_wire_no').is(':checked') ? false : true,
            ipv6: $('#_mongo_settingsipv6_no').is(':checked') ? false : true,
            authorization: $('#_mongo_settings_role_no').is(':checked') ? false : true,
        };
        sendMongoDBSettings(JSON.stringify(settings_form), restart === undefined ? 0 : 1,
        function (response) {
            mongo_file_editor.setValue(response.file_content);
            UnlockUI(response.status_server, response.db_list !== null ? response.db_list : undefined);
            alertSuccess(response.status_server);
        }, function () {
            UnlockUI('running');
        });
    }
    
    // console.log('settings_form', settings_form);
}

function toggleMongoConfEditor(type){
    let show = '#_mongdb_settings_wrapper_';
    let hide = '#_mongo_settings_file_editor_';
    if(type === 1){
        hide = '#_mongdb_settings_wrapper_';
        show = '#_mongo_settings_file_editor_';
    }
    slideToggle(show, hide, function(){
        advanceTab();
    });
}
function sendMongoDBSettings(settings, restart, success, cleaner) {
    $.ajax({
        type: "POST",
        url: "./loader_ajax.php?ajax=mongodb_manager&acc=save_settings",
        data: 'settings=' + settings + '&restart=' + restart,
        complete: function (response) {
            let resp_data = {}
            try {
                resp_data = response.hasOwnProperty('responseJson') ? response.responseJson : JSON.parse(response.responseText);
            } catch (error) {
                $.gritter.add({
                    title: '{{lang.LABMON20}}',
                    text: '{{lang.LABMON23}}',
                    time: 3500,
                    close_icon: '',
                    icon: 'icomoon-icon-power',
                    class_name: 'error-notice'
                });
                cleaner();
                return;
            }
            if (resp_data.hasOwnProperty('status') && resp_data.status === 'success') {
                success(resp_data);
            } else {
                let message_error = '{{lang.LABMON23}}';
                if (resp_data.hasOwnProperty('code')) {
                    if (resp_data.code == 2) {
                        message_error = '{{lang.LABMON28}}';
                    } else if (resp_data.code == 1) {
                        message_error = 'Invalid data';
                    }
                }
                $.gritter.add({
                    title: '{{lang.LABMON20}}',
                    text: message_error,
                    time: 3500,
                    close_icon: '',
                    icon: 'icomoon-icon-power',
                    class_name: 'error-notice'
                });
                cleaner();
            }
        }
    });
}
function sendMongoDBSettingsFile(file_content, restart, success, cleaner) {
    $.ajax({
        type: "POST",
        url: "./loader_ajax.php?ajax=mongodb_manager&acc=save_settings_file",
        data: 'file_content=' + Base64.encode(file_content) + '&restart=' + restart,
        complete: function (response) {
            let resp_data = {}
            try {
                resp_data = response.hasOwnProperty('responseJson') ? response.responseJson : JSON.parse(response.responseText);
            } catch (error) {
                $.gritter.add({
                    title: '{{lang.LABMON20}}',
                    text: '{{lang.LABMON23}}',
                    time: 3500,
                    close_icon: '',
                    icon: 'icomoon-icon-power',
                    class_name: 'error-notice'
                });
                cleaner();
                return;
            }
            if (resp_data.hasOwnProperty('status') && resp_data.status === 'success') {
                success(resp_data);
            } else {
                let message_error = '{{lang.LABMON23}}';
                if (resp_data.hasOwnProperty('code')) {
                    if (resp_data.code == 2) {
                        message_error = '{{lang.LABMON28}}';
                    } else if (resp_data.code == 1) {
                        message_error = 'Invalid data';
                    }
                }
                $.gritter.add({
                    title: '{{lang.LABMON20}}',
                    text: message_error,
                    time: 3500,
                    close_icon: '',
                    icon: 'icomoon-icon-power',
                    class_name: 'error-notice'
                });
                cleaner();
            }
        }
    });
}