server {
	listen %ip%:%nginx_port%;	
	server_name %domain_idn% %alias_idn%;

	access_log /usr/local/apache/domlogs/%domain%.bytes bytes;
	access_log /usr/local/apache/domlogs/%domain%.log combined;
	error_log /usr/local/apache/domlogs/%domain%.error.log error;

	location / {
		proxy_set_header X-Real-IP $remote_addr;
        proxy_set_header X-Forwarded-For $proxy_add_x_forwarded_for;
        proxy_set_header X-Forwarded-Proto $scheme;
        proxy_set_header Host $http_host;
        proxy_set_header X-NginX-Proxy true;

        proxy_pass http://127.0.0.1:%proxy_port%;
        proxy_redirect off;

        # Socket.IO Support
        proxy_http_version 1.1;
        proxy_set_header Upgrade $http_upgrade;
        proxy_set_header Connection "upgrade";
		}
		
		error_page 405 = @backend;
		error_page 500 = @custom;
		add_header X-Cache "HIT from Backend";
		proxy_pass %proxy_protocol%://%proxy_ip%:%proxy_port%;
		include proxy.inc;
		return 301 https://$server_name$request_uri;
	}

	location @backend {
		internal;
		proxy_pass %proxy_protocol%://%proxy_ip%:%proxy_port%;
		include proxy.inc;
	}

	location @custom {
		internal;
		proxy_pass %proxy_protocol%://%proxy_ip%:%proxy_port%;
		include proxy.inc;
	}

	location ~ .*\.(php|jsp|cgi|pl|py)?$ {
		proxy_pass %proxy_protocol%://%proxy_ip%:%proxy_port%;
		include proxy.inc;
	}

	location ~ /\.ht    {deny all;}
	location ~ /\.svn/  {deny all;}
	location ~ /\.git/  {deny all;}
	location ~ /\.hg/   {deny all;}
	location ~ /\.bzr/  {deny all;}

	disable_symlinks if_not_owner from=%docroot%;

	location /.well-known/acme-challenge {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}

	location /.well-known/pki-validation {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}
}

server {
	listen %ip%:%nginx_port%;	
	server_name webmail.%domain_idn%;

	access_log /usr/local/apache/domlogs/%domain%.bytes bytes;
	access_log /usr/local/apache/domlogs/%domain%.log combined;
	error_log /usr/local/apache/domlogs/%domain%.error.log error;

	location / {
		proxy_pass  http://127.0.0.1:2095;
		include proxy.inc;
		return 301 https://$server_name$request_uri;
	}

	location ~ /\.ht    {deny all;}
	location ~ /\.svn/  {deny all;}
	location ~ /\.git/  {deny all;}
	location ~ /\.hg/   {deny all;}
	location ~ /\.bzr/  {deny all;}

	disable_symlinks if_not_owner from=%docroot%;

	location /.well-known/acme-challenge {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}

	location /.well-known/pki-validation {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}
}

server {
	listen %ip%:%nginx_port%;	
	server_name mail.%domain_idn%;

	access_log /usr/local/apache/domlogs/%domain%.bytes bytes;
	access_log /usr/local/apache/domlogs/%domain%.log combined;
	error_log /usr/local/apache/domlogs/%domain%.error.log error;

	location / {
		proxy_pass  http://127.0.0.1:2095;
		include proxy.inc;
		return 301 https://$server_name$request_uri;
	}

	location ~ /\.ht    {deny all;}
	location ~ /\.svn/  {deny all;}
	location ~ /\.git/  {deny all;}
	location ~ /\.hg/   {deny all;}
	location ~ /\.bzr/  {deny all;}

	disable_symlinks if_not_owner from=%docroot%;

	location /.well-known/acme-challenge {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}

	location /.well-known/pki-validation {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}
}

server {
	listen %ip%:%nginx_port%;	
	server_name cpanel.%domain_idn%;

	access_log /usr/local/apache/domlogs/%domain%.bytes bytes;
	access_log /usr/local/apache/domlogs/%domain%.log combined;
	error_log /usr/local/apache/domlogs/%domain%.error.log error;

	location / {
		proxy_pass  https://127.0.0.1:2083;
		include proxy.inc;
		return 301 https://$server_name$request_uri;
	}

	location /pma {
		proxy_pass  https://127.0.0.1:2031;
		include proxy.inc;
		return 301 https://$server_name$request_uri;
	}

	location /roundcube {
		proxy_pass  https://127.0.0.1:2031;
		include proxy.inc;
		return 301 https://$server_name$request_uri;
	}

	location ~ /\.ht    {deny all;}
	location ~ /\.svn/  {deny all;}
	location ~ /\.git/  {deny all;}
	location ~ /\.hg/   {deny all;}
	location ~ /\.bzr/  {deny all;}

	disable_symlinks if_not_owner from=%docroot%;

	location /.well-known/acme-challenge {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}

	location /.well-known/pki-validation {
		default_type "text/plain";
		alias /usr/local/apache/autossl_tmp/.well-known/acme-challenge;
	}
}
