backend %backend_domain% {
	.host = "%proxy_ip%";
	.port = "%proxy_port%";
}

sub vcl_recv {
	if (req.http.host ~ "%domain%") {
		set req.backend_hint = %backend_domain%;

		# Always cache the following file types for all users.
		if (req.url ~ "(?i)\.(png|gif|jpeg|jpg|ico|swf|css|js|html|htm)(\?[a-z0-9]+)?$") {
			unset req.http.Cookie;
		}

		# Remove any Google Analytics based cookies
		set req.http.Cookie = regsuball(req.http.Cookie, "has_js=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "__utm.=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "_ga=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "utmctr=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "utmcmd.=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "utmccn.=[^;]+(; )?", "");

		# Do not cache AJAX requests.
		if (req.http.X-Requested-With == "XMLHttpRequest") {
			return(pass);
		}

		# Post requests will not be cached
		if (req.http.Authorization || req.method == "POST") {
			return (pass);
		}
		if (req.method != "GET" && req.method != "HEAD") {
			return (pass);
		}

		# Do not cache Authorized requests.
		if (req.http.Authorization) {
			return(pass);
		}

		# LetsEncrypt Certbot passthrough
		if (req.url ~ "^/\.well-known/acme-challenge/") {
			return (pass);
		}

		if (req.url ~ "^/\.well-known/pki-validation/") {
			return (pass);
		}

		# Forward client's IP to the backend
		if (req.restarts == 0) {
			if (req.http.X-Real-IP) {
				set req.http.X-Forwarded-For = req.http.X-Real-IP;
			} else if (req.http.X-Forwarded-For) {
				set req.http.X-Forwarded-For = req.http.X-Forwarded-For + ", " + client.ip;
			} else {
				set req.http.X-Forwarded-For = client.ip;
			}
		}

		### Wordpress ###
		if (req.url ~ "(wp-admin|post\.php|edit\.php|wp-login)") {
			return(pass);
		}
		if (req.url ~ "/wp-cron.php" || req.url ~ "preview=true") {
			return (pass);
		}

		# WP-Affiliate
		if ( req.url ~ "\?ref=" ) {
			return (pass);
		}

		set req.http.Cookie = regsuball(req.http.Cookie, "wp-settings-1=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "wp-settings-time-1=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "wordpress_test_cookie=[^;]+(; )?", "");
		set req.http.Cookie = regsuball(req.http.Cookie, "PHPSESSID=[^;]+(; )?", "");

		return (hash);
	}
}